############################################################################
#
#  Program:         ARPACK
#
#  Module:          Makefile
#
#  Purpose:         Top-level Makefile
#
#  Creation date:   February 22, 1996
#
#  Modified:
#
#  Send bug reports, comments or suggestions to arpack@caam.rice.edu
#
############################################################################

ARMAKE=ARmakeg95.inc
include $(ARMAKE)
include OBjectg.make
PRECISIONS = all

LIBARPACK=../libarpack$(PLAT)
ARPACKLIBMAX=$(LIBARPACK)max.$(LIBEXT)
ARPACKLIBMIN=$(LIBARPACK)min.$(LIBEXT)
#single double complex complex16
#PRECISIONS = double ddrv

#  If LAPACK and BLAS are not installed on you system, and you are going 
#  to use the driver programs in the EXAMPLES directory,  you need to add 
#  sdrv(for single precision), ddrv(for double precision), 
#  cdrv(for single precision complex), or zdrv(for double precision complex) 
#  to the definition of PRECISION.

############################################################################
#
#  The library can be set up to include routines for any combination of the
#  four PRECISIONS.  First, modify the definitions in ARmake.inc to match 
#  your library archiver, compiler, and the options to be used.
#
#  Sample ARmake.inc's can be found in the directory ARMAKES
#  
#  Then to create or add to the library, enter make lib after having
#  modified the environment variable PRECISIONS defined in this Makefile.
#
#       make lib
#  creates the library for serial ARPACK,
#
#  The name of the libraries are defined in the file called ARmake.inc and
#  are created at this directory level.
#
#  To remove the object files after the libraries and testing executables
#  are created, enter
#       make clean
#
############################################################################

min: dir old minlib mindll

pack: dir old packlib packdll

all: dir old arpacklib dll

old:
	echo "saving old libraries..."
	mkdir -p old
	mv -f $(ARPACKDLL).$(DLLEXT) $(ARPACKLIB) old
	echo "done."

dir:
	mkdir -p $(OBJDIR)

dll: arpacklib dir
	( \
	 cd $(OBJDIR) ; \
	$(FC) $(LDFLAGS) -s -shared  \
		-o ../$(ARPACKDLL).$(DLLEXT) \
	 	$(OBJECTS) ; \
	 cd .. ;\
	);
mindll: minlib dir
	( \
	cd $(OBJDIR) ; \
	rm *.$(OE);\
	$(ECHO) "Building $(ARPACKDLL)min.$(DLLEXT) linked with installed LAPACK and BLAS...";\
	cp ../SRC/*.$(OE) ../UTIL/*.$(OE) . ;\
	$(FC) $(LDFLAGS) -s -shared  \
	      -o ../$(ARPACKDLL)min.$(DLLEXT) \
	      *.$(OE) -L$(DLLDIR) -l$(BLASDLL) -l$(LAPACKDLL);\
	$(ECHO) "Done.";\
	rm *.$(OE);\
	cd .. ;\
	);

minlib:	
	@( \
	export ARMAKE=../$(ARMAKE);\
	$(ECHO) "Building Minimal ARPACK, LAPACK distribution assumed installed ...";\
	for f in $(MINDIRS); \
	do \
		$(CD) $$f; \
		$(ECHO) Making lib in $$f; \
		$(MAKE) $(PRECISIONS); \
		cp *.o $(OBJDIR) ; \
		$(CD) ..; \
	done;\
	mv libarpack$(PLAT).$(LIBEXT) libarpack$(PLAT)min.$(LIBEXT);\
	$(RANLIB) $(ARPACKLIBMIN);\
	$(ECHO) "Done." )

packlib:	
	@( \
	export ARMAKE=../$(ARMAKE);\
	for f in $(MINDIRS); \
	do \
		$(CD) $$f; \
		$(ECHO) Making lib in $$f; \
		$(MAKE) $(PRECISIONS); \
		cp *.o $(OBJDIR) ; \
		$(CD) ..; \
	done; \
	$(CD) $(OBJDIR);\
	$(ECHO) "Packing ARPACK, BLAS and LAPACK together...";\
	$(AR) $(AREXTRACT) $(BLASLIB) ;\
	$(AR) $(AREXTRACT) $(LAPACKLIB) ;\
	$(AR) $(ARFLAGS) $(ARPACKLIBMAX) *.$(OE) ;\
	$(RANLIB) $(ARPACKLIB);\
	$(ECHO) "Done.";\
	$(CD) ..  )

packdll: packlib dir
	@( \
	cd $(OBJDIR) ; \
	rm *.$(OE);\
	$(AR) $(AREXTRACT) $(ARPACKLIBMAX) ;\
	$(ECHO) "Building $(ARPACKDLL)max.$(DLLEXT)...";\
	$(FC) $(LDFLAGS) -s -shared  \
	      $(OF) ../$(ARPACKDLL)max.$(DLLEXT) \
	      *.$(OE) ;\
	$(ECHO) "done.";\
	rm *.$(OE);\
	cd .. ;\
	);
clean: cleanlib

arpacklib:
	@( \
	export ARMAKE=../$(ARMAKE);\
	for f in $(DIRS); \
	do \
		$(CD) $$f; \
		$(ECHO) Making lib in $$f; \
		$(MAKE) $(PRECISIONS); \
		cp *.o $(OBJDIR) ; \
		$(CD) ..; \
	done );
	$(RANLIB) $(ARPACKLIB)

cleantest:

cleanlib:
	(\
	export ARMAKE=$(home)/$(ARMAKE);\
	for f in $(DIRS);\
	do \
	  	$(CD) $$f; \
	  	$(MAKE) clean ; \
		$(CD) ..;\
	done );
	( rm -fr $(OBJDIR)/* )

distclean: cleanlib
	rm -fr $(ARPACKLIB)
	rm -fr $(ARPACKDLL).*

help:
    @$(ECHO) "usage: make ?"
